aboutsummaryrefslogtreecommitdiff
path: root/cast/streaming/receiver_session.h
diff options
context:
space:
mode:
authorJordan Bayles <jophba@chromium.org>2021-04-02 06:32:00 +0000
committerJordan Bayles <jophba@chromium.org>2021-04-02 06:33:29 +0000
commit7e8744af012d98e23e70882f30bbae7380d142d4 (patch)
treead8536e30fb394fd50ff486734066169bae6a5ec /cast/streaming/receiver_session.h
parente84a151b90d953c2185c802a45f6da7c70e65288 (diff)
downloadopenscreen-7e8744af012d98e23e70882f30bbae7380d142d4.tar.gz
Revert "[Cast] Rename Negotiate/OnNegotiated methods"
This reverts commit 21f04aefd1b06a959576202fc3a7616bc4de0b1d. Reason for revert: Rename breaks Fuchsia build. Original change's description: > [Cast] Rename Negotiate/OnNegotiated methods > > This patch renames SenderSession Negotiate to NegotiateMirroring and > OnNegotiated to OnMirroringNegotiated, in advance of a larger patch that > exposes remoting on the SenderSession. > > Bug: b/184186374 > Change-Id: Ibfa38a822d6fdf5a39ebb83ef493442451fcc91e > Reviewed-on: https://chromium-review.googlesource.com/c/openscreen/+/2798518 > Reviewed-by: Ryan Keane <rwkeane@google.com> > Commit-Queue: Jordan Bayles <jophba@chromium.org> Bug: b/184186374 Change-Id: I8ac2534d47e27a3fa151b72aa0098688a771a410 Reviewed-on: https://chromium-review.googlesource.com/c/openscreen/+/2801912 Bot-Commit: Rubber Stamper <rubber-stamper@appspot.gserviceaccount.com>
Diffstat (limited to 'cast/streaming/receiver_session.h')
-rw-r--r--cast/streaming/receiver_session.h16
1 files changed, 7 insertions, 9 deletions
diff --git a/cast/streaming/receiver_session.h b/cast/streaming/receiver_session.h
index b8365a36..b29b6d52 100644
--- a/cast/streaming/receiver_session.h
+++ b/cast/streaming/receiver_session.h
@@ -51,25 +51,23 @@ class ReceiverSession final : public Environment::SocketSubscriber {
};
// The embedder should provide a client for handling connections.
// When a connection is established, the OnMirroringNegotiated callback is
// called.
class Client {
public:
enum ReceiversDestroyingReason { kEndOfSession, kRenegotiated };
// Called when a new set of receivers has been negotiated. This may be
// called multiple times during a session, as renegotiations occur.
- virtual void OnMirroringNegotiated(const ReceiverSession* session,
- ConfiguredReceivers receivers) = 0;
+ virtual void OnNegotiated(const ReceiverSession* session,
+ ConfiguredReceivers receivers) = 0;
// Called immediately preceding the destruction of this session's receivers.
// If |reason| is |kEndOfSession|, OnMirroringNegotiated() will never be
// called again; if it is |kRenegotiated|, OnMirroringNegotiated() will be
// called again soon with a new set of Receivers to use.
//
// Before returning, the implementation must ensure that all references to
// the Receivers, from the last call to OnMirroringNegotiated(), have been
// cleared.
virtual void OnReceiversDestroying(const ReceiverSession* session,
ReceiversDestroyingReason reason) = 0;
@@ -51,25 +51,23 @@ class ReceiverSession final : public Environment::SocketSubscriber {
};
// The embedder should provide a client for handling connections.
- // When a connection is established, the OnMirroringNegotiated callback is
- // called.
+ // When a connection is established, the OnNegotiated callback is called.
class Client {
public:
@@ -51,25 +51,23 @@ class ReceiverSession final : public Environment::SocketSubscriber {
// Called immediately preceding the destruction of this session's receivers.
- // If |reason| is |kEndOfSession|, OnMirroringNegotiated() will never be
- // called again; if it is |kRenegotiated|, OnMirroringNegotiated() will be
- // called again soon with a new set of Receivers to use.
+ // If |reason| is |kEndOfSession|, OnNegotiated() will never be called
+ // again; if it is |kRenegotiated|, OnNegotiated() will be called again
+ // soon with a new set of Receivers to use.
//
// Before returning, the implementation must ensure that all references to
@@ -51,25 +51,23 @@ class ReceiverSession final : public Environment::SocketSubscriber {
//
// Before returning, the implementation must ensure that all references to
- // the Receivers, from the last call to OnMirroringNegotiated(), have been
- // cleared.
+ // the Receivers, from the last call to OnNegotiated(), have been cleared.
virtual void OnReceiversDestroying(const ReceiverSession* session,
ReceiversDestroyingReason reason) = 0;